==> fw4spl_0.9.2.orig.tar.gz: fw4spl-0.9.2/SrcLib/core/fwGuiQt/src/fwGuiQt/container/QtMenuContainer.cpp <==
/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2014.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#include <QMenu>
#include "fwGuiQt/container/QtMenuContainer.hpp"

namespace fwGuiQt
{
namespace container
{

//-----------------------------------------------------------------------------

QtMenuContainer::QtMenuContainer(::fwGui::GuiBaseObject::Key key) throw()
{}

//-----------------------------------------------------------------------------

QtMenuContainer::~QtMenuContainer() throw()
{}

//-----------------------------------------------------------------------------

void QtMenuContainer::clean()
{
    SLM_ASSERT("Sorry, Qt menu not yet initialized, cleaning impossible", m_menu);
    m_menu->clear();
}

//-----------------------------------------------------------------------------

void QtMenuContainer::destroyContainer()
{
    SLM_ASSERT("Sorry, Qt menu not yet initialized, cleaning impossible", m_menu);
    delete m_menu;
}

//-----------------------------------------------------------------------------

void QtMenuContainer::setQtMenu(QMenu *menu)
{
    this->m_menu = menu;
}

//-----------------------------------------------------------------------------

QMenu* QtMenuContainer::getQtMenu()
{
    return this->m_menu;
}

//-----------------------------------------------------------------------------

} // namespace container
} // namespace fwGuiQt

==> fw4spl_17.2.0.orig.tar.gz: fw4spl-17.2.0/SrcLib/core/fwGuiQt/src/fwGuiQt/container/QtMenuContainer.cpp <==
/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2016.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#include <QMenu>
#include "fwGuiQt/container/QtMenuContainer.hpp"

namespace fwGuiQt
{
namespace container
{

//-----------------------------------------------------------------------------

QtMenuContainer::QtMenuContainer(::fwGui::GuiBaseObject::Key key) noexcept
{
}

//-----------------------------------------------------------------------------

QtMenuContainer::~QtMenuContainer() noexcept
{
}

//-----------------------------------------------------------------------------

void QtMenuContainer::clean()
{
    SLM_ASSERT("The Qt menu is not yet initialized, cleaning is thus impossible", m_menu);
    m_menu->clear();
}

//-----------------------------------------------------------------------------

void QtMenuContainer::destroyContainer()
{
    SLM_ASSERT("The Qt menu not yet initialized, cleaning is thus impossible", m_menu);
    delete m_menu;
}

//-----------------------------------------------------------------------------

void QtMenuContainer::setQtMenu(QMenu *menu)
{
    this->m_menu = menu;
}

//-----------------------------------------------------------------------------

QMenu* QtMenuContainer::getQtMenu()
{
    return this->m_menu;
}

//-----------------------------------------------------------------------------

} // namespace container
} // namespace fwGuiQt
